@@ -6,7 +6,7 @@
  * See http://mod-qos.sourceforge.net/ for further
  * details.
  *
- * Copyright (C) 2017 Pascal Buchbinder
+ * Copyright (C) 2019 Pascal Buchbinder
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -25,7 +25,7 @@
  *
  */
 
-static const char revision[] = "$Id: qspng.c,v 1.24 2017-06-29 05:24:33 pbuchbinder Exp $";
+static const char revision[] = "$Id: qspng.c 2542 2019-02-22 06:37:10Z pbuchbinder $";
 
 #include <stdio.h>
 #include <string.h>
@@ -65,6 +65,10 @@ static const qs_png_elt_t qs_png_elts[] = {
   { "esco", "established connections per minute", 40, 95, 140 },
   { "av", "average response time", 40, 95, 140 },
   { "avms", "average response time in milliseconds", 45, 95, 135 },
+  { "0-49ms", "requests duration 0-49ms", 45, 100, 180 },
+  { "50-99ms", "requests duration 50-99ms", 45, 100, 180 },
+  { "100-499ms", "requests duration 100-499ms", 45, 100, 180 },
+  { "500-999ms", "requests duration 500-999ms", 45, 100, 180 },
   { "<1s", "requests faster than 1 second", 35, 95, 180 },
   { "1s", "requests faster or equal than 1 second", 35, 90, 180 },
   { "2s", "requests with 2 seconds response time", 30, 85, 180 },
@@ -604,7 +608,7 @@ static void usage(char *cmd, int man) {
   printf("\n");
   if(man) {
     printf(".SH SEE ALSO\n");
-    printf("qsexec(1), qsfilter2(1), qsgeo(1), qsgrep(1), qshead(1), qslogger(1), qslog(1), qsrotate(1), qssign(1), qstail(1)\n");
+    printf("qsdt(1), qsexec(1), qsfilter2(1), qsgeo(1), qsgrep(1), qshead(1), qslogger(1), qslog(1), qsre(1), qsrespeed(1), qsrotate(1), qssign(1), qstail(1)\n");
     printf(".SH AUTHOR\n");
     printf("Pascal Buchbinder, http://mod-qos.sourceforge.net/\n");
   } else {
